There are a number of ways to build an AEA:
<ul>
	<li>To start with, we recommended you build an AEA project step-by-step with the CLI tool as demonstrated in the <a href="../quickstart/" target=_blank>quick start</a> guide and described <a href="../build-aea-step-by-step/" target=_blank>here</a>. See information on the CLI tool <a href="../cli-how-to/" target=_blank>here</a>.</li>
	<li>Using the CLI <code>aea fetch</code> command, pull in an already built project and run as is or extend it to your needs.</li>
	<li>The last option is to build an AEA programmatically as described <a href="../build-aea-programmatically/" target=_blank>here</a>.</li>
</ul>

Sometimes, an AEA is more than is required for the task at hand. In particular, an AEA is much more than just an agent. In those cases, we suggest you have a look at the following two guides:
<ul>
	<li> the <a href="../agent-vs-aea/" target=_blank>AEA vs Agents</a> guide shows the difference between an agent and an AEA in code,
	<li> the <a href="../multiplexer-standalone/" target=_blank>Use multiplexer standalone</a> guide shows how to use the multiplexer on its own to receive and send envelopes.
</ul>

<br />